CODE_OF_CONDUCT.md
COPYING
CREDITS
FAQ
HISTORY
INSTALL
README.md
RELEASE-NOTES-1.45
SECURITY
UPGRADE
api.php
autoload.php
bundlesize.config.json
cache
composer.json
composer.local.json-sample
docs
extensions
images
img_auth.php
includes
index.php
jsdoc.json
languages
load.php
maintenance
mw-config
opensearch_desc.php
resources
rest.php
skins
sql
tests
thumb.php
thumb_handler.php
vendor
LocalSettings.php